@@ -1,7 +1,7 @@
 package Rope;
 
 use 5.006; use strict; use warnings;
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use Rope::Object;
 my (%META, %PRO);
@@ -321,7 +321,7 @@ Rope - Tied objects
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
@@ -372,41 +372,41 @@ Version 0.09
 
 =head1 DESCRIPTION
 
-C<Rope> is an Object Orientation system that is built on top of perls core hash tying implementation. It extends the functionality which is available with all the modern features you would expect from an modern OO system. This includes clear class and role definitions. With rope you also get out of the box sorted objects, where the order you define you class persists.
+C<Rope> is an Object Orientation system that is built on top of perls core hash tying implementation. It extends the functionality which is available with all the modern features you would expect from an modern OO system. This includes clear class and role definitions. With Rope you also get out of the box sorted objects, where the order you define persists.
 
 =head1 CONFIGURE PROPERTIES
 
 =head2 initable
 
-If set to a true value then this property can be initialised during the object creationg, when calling ->new(%params). If set to false then on initialisation ion the code will die with a relevant error. (Cannot initalise Object ($name) property ($key) as initable is not set to true.)
+If set to a true value then this property can be initialised during the object creationg, when calling ->new(%params). If set to false then on initialisation the code will die with a relevant error when you try to initialise it. (Cannot initalise Object ($name) property ($key) as initable is not set to true.)
 
 =head2 writeable
 
-If set to a true value then this property value can be updated after initialisation with any other value. If set to false then the code will die with a relevant error. (Cannot set Object ($name) property ($key) it is only readable)
+If set to a true value then this property value can be updated after initialisation with any other value. If set to false then the code will die with a relevant error. If writeable is true then configurable is not checked and redundent. (Cannot set Object ($name) property ($key) it is only readable)
 
 =head2 configurable
 
-If set to a true value then this property value can be updated after initialisation with a value that matches the type of the existing. If you try to set a value which is not of the same type the error will die with a relevant error. (Cannot change Object ($name) property ($key) type). If you set to false and writeable is also false you will get the same error as writeable false.
+If set to a true value then this property value can be updated after initialisation with a value that matches the type of the existing. If you try to set a value which is not of the same type the code will die with a relevant error. (Cannot change Object ($name) property ($key) type). If you set to false and writeable is also false you will get the same error as writeable false.
 
 =head2 enumerable
 
-If set to a true value then the property will be enumerable when you itterate the object for example when you call keys %{$self}. If set to false then the property will be hidden from any iteration. Note also that when itterating your object keys are already ordered based on the order they were assigned.
+If set to a true value then the property will be enumerable when you itterate the object for example when you call keys %{$self}. If set to false then the property will be hidden from any itteration. Note also that when itterating your object keys are already ordered based on the order they were assigned.
 
 =head2 required
 
-If set to a true value then this property is required at initialisation, either by a value key being set or via passing into ->new. I would suggest using this in conjunction with initable when you require a value is passed. If no value is passed an required is set to true then the code will die with a relevant error. (Required property ($key) in object ($object) not set)
+If set to a true value then this property is required at initialisation, either by a value key being set or via passing into ->new. I would suggest using this in conjunction with initable when you require a value is passed. If no value is passed and required is set to true then the code will die with a relevant error. (Required property ($key) in object ($object) not set)
 
 =head2 type
 
-The type property/key expects a code ref to passed, all values that are then set either during initialisation or writing from with the following code will run through this ref. Rope expects that you return the final value from this sub routine so you can use coercion via a type.
+The type property/key expects a code ref to be passed, all values that are then set either during initialisation or writing will run through this ref. Rope expects that you return the final value from this ref so you can use coercion via a type.
 
 =head2 builder
 
-The buidler property/key expects either a code ref or a scalar that represents the name of a sub routine in your class (currently not another function/property but may extend in the future). It expects the value for that property to be returned from either the code ref or sub routine. Within a builder you can also add new properties to your object by exstend the passed defintion, when extending this way i would suggest using ++$_[0]->{keys} to set the index so that sorting is persistent further down the line.
+The buidler property/key expects either a code ref or a scalar that represents the name of a sub routine in your class (currently not functions/properties but may extend in the future). It expects the value for that property to be returned from either the code ref or sub routine. Within a builder you can also add new properties to your object by extending the passed defintion, when extending this way I would suggest using ++$_[0]->{keys} to set the index so that sorting is persistent further down the line.
 
 =head2 index
 
-The index property/key expects an integer, if you do not set then this integer is automatically generated and associated to the property. You will only want to set this is you always want to have a property last when itterating
+The index property/key expects an integer, if you do not set then this integer it's automatically generated and associated to the property. You will only want to set this is you always want to have a property last when itterating
 
 =head1 KEYWORDS
 
